**CrysPy** is a crystallographic python library for polarized neutron diffraction data analysis.
The package allows the data treatment both for powders and single-crystal samples. Nuclear and (commensurate) magnetic structures refinement can be also perfomed based on the unpolarized neutron diffraction and X-ray diffraction data.

Features
--------
- CrysPy allows one to analyse the local magnetic anisotropy by the susceptibility approach  and the spin/magnetization densities reconstruction by maximume entropy procedure based on polarized neutron diffraction experiments;
- Core CIF dictionary of the  IUCr is used to cover the requirements of archiving and exchanging the data and derived magnetic and structural results;
- The library is written in Python. It can be used in Jupyter notebooks under the main platforms Windows, MacOSX and Linux or as a standalone application with a simple graphical user interface "CrysPy Editor".


For more information please visit the site `cryspy.fr <https://www.cryspy.fr>`_.

Try `CrysPy in a Web Browser <https://www.google.com/url?q=https%3A%2F%2Fmybinder.org%2Fv2%2Fgh%2Fikibalin%2Fcryspy_webapp%2FHEAD%3Furlpath%3Dvoila%252Frender%252Fcryspy_webapp.ipynb&sa=D&sntz=1&usg=AOvVaw3J-PERjuf-b-hp1OuoT4cK>`_ before installing it on your PC.

Copyright and License
---------------------

MIT License

Copyright (c) 2018-2020 Iurii Kibalin
https://github.com/ikibalin/cryspy

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
